# 👷 Contributing

There are many ways you can contribute to the project. Here are some ideas:

- Build a new Upkie: report any gap in the [build instructions](https://github.com/upkie/upkie/wiki) and share your progress in the [discussions](https://github.com/upkie/upkie/discussions/)
- Name your robot and describe it [Show and tell](https://github.com/upkie/upkie/discussions/categories/show-and-tell)
- Pick one of the [open issues](https://github.com/upkie/upkie/issues?q=is%3Aissue+is%3Aopen)
- Suggest improvements to the [documentation](https://upkie.github.io/upkie/)

Feel free to join the [chat](https://app.element.io/#/room/#tasts-robots:matrix.org) to share what you're up to with other Upkie makers.
